matminer.featurizers package
============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   matminer.featurizers.composition
   matminer.featurizers.site
   matminer.featurizers.structure
   matminer.featurizers.tests
   matminer.featurizers.utils

Submodules
----------

matminer.featurizers.bandstructure module
-----------------------------------------

.. automodule:: matminer.featurizers.bandstructure
   :members:
   :undoc-members:
   :show-inheritance:

matminer.featurizers.base module
--------------------------------

.. automodule:: matminer.featurizers.base
   :members:
   :undoc-members:
   :show-inheritance:

matminer.featurizers.conversions module
---------------------------------------

.. automodule:: matminer.featurizers.conversions
   :members:
   :undoc-members:
   :show-inheritance:

matminer.featurizers.dos module
-------------------------------

.. automodule:: matminer.featurizers.dos
   :members:
   :undoc-members:
   :show-inheritance:

matminer.featurizers.function module
------------------------------------

.. automodule:: matminer.featurizers.function
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: matminer.featurizers
   :members:
   :undoc-members:
   :show-inheritance:
